@@ -4,7 +4,8 @@
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
 set.seed(290875)
-options(prompt = "R> ", width = 63, # digits = 4,
+options(prompt = "R> ", continue = "+  ",
+    width = 63, # digits = 4,
     SweaveHooks = list(leftpar = function()
         par(mai = par("mai") * c(1, 1.05, 1, 1))))
 HSAURpkg <- require("HSAUR")
@@ -13,15 +14,30 @@ rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
 a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
+book <- TRUE
+refs <- cbind(c("AItR", "SI", "CI", "ANOVA", "MLR", "GLM",
+                "DE", "RP", "SA", "ALDI", "ALDII", "MA", "PCA",
+                "MDS", "CA"), 1:15)
+ch <- function(x, book = TRUE) {
+    ch <- refs[which(refs[,1] == x),]
+    if (book) {
+        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
+    } else {
+        return(paste("Chapter~\\\\ref{", ch[2], "}", sep = ""))
+    }
+}
 
 
 ###################################################
 ### chunk number 2: PCA-heptathlon-recode
 ###################################################
 data("heptathlon", package = "HSAUR")
-heptathlon$hurdles <- max(heptathlon$hurdles) - heptathlon$hurdles
-heptathlon$run200m <- max(heptathlon$run200m) - heptathlon$run200m
-heptathlon$run800m <- max(heptathlon$run800m) - heptathlon$run800m
+heptathlon$hurdles <- max(heptathlon$hurdles) -
+    heptathlon$hurdles
+heptathlon$run200m <- max(heptathlon$run200m) -
+    heptathlon$run200m
+heptathlon$run800m <- max(heptathlon$run800m) -
+    heptathlon$run800m
 
 
 ###################################################
@@ -81,7 +97,8 @@ scale <- heptathlon_pca$scale
 ### chunk number 11: PCA-heptathlon-s1
 ###################################################
 hm <- as.matrix(heptathlon[,-score])
-drop(scale(hm, center = center, scale = scale) %*% heptathlon_pca$rotation[,1])
+drop(scale(hm, center = center, scale = scale) %*%
+     heptathlon_pca$rotation[,1])
 
 
 ###################################################
