@@ -4,7 +4,8 @@
 rm(list = ls())
 if (!file.exists("tables")) dir.create("tables")
 set.seed(290875)
-options(prompt = "R> ", width = 63, # digits = 4,
+options(prompt = "R> ", continue = "+  ",
+    width = 63, # digits = 4,
     SweaveHooks = list(leftpar = function()
         par(mai = par("mai") * c(1, 1.05, 1, 1))))
 HSAURpkg <- require("HSAUR")
@@ -13,6 +14,18 @@ rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
 a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
+book <- TRUE
+refs <- cbind(c("AItR", "SI", "CI", "ANOVA", "MLR", "GLM",
+                "DE", "RP", "SA", "ALDI", "ALDII", "MA", "PCA",
+                "MDS", "CA"), 1:15)
+ch <- function(x, book = TRUE) {
+    ch <- refs[which(refs[,1] == x),]
+    if (book) {
+        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
+    } else {
+        return(paste("Chapter~\\\\ref{", ch[2], "}", sep = ""))
+    }
+}
 
 
 ###################################################
@@ -42,13 +55,15 @@ Forbes2000 <- subset(Forbes2000, !is.na(profits))
 ### chunk number 4: RP-Forbes-rpart
 ###################################################
 library("rpart")
-forbes_rpart <- rpart(profits ~ assets + marketvalue + sales, data = Forbes2000)
+forbes_rpart <- rpart(profits ~ assets + marketvalue + sales,
+                      data = Forbes2000)
 
 
 ###################################################
 ### chunk number 5: RP-Forbes-initial
 ###################################################
-plot(forbes_rpart, uniform = TRUE, margin = 0.1, branch = 0.5, compress = TRUE)
+plot(forbes_rpart, uniform = TRUE, margin = 0.1, branch = 0.5,
+     compress = TRUE)
 text(forbes_rpart)
 
 
@@ -70,18 +85,21 @@ forbes_prune <- prune(forbes_rpart, cp = cp)
 ### chunk number 8: RP-Forbes-plot
 ###################################################
 layout(matrix(1:2, nc = 1))
-plot(forbes_prune, uniform = TRUE, margin = 0.1, branch = 0.5, compress = TRUE)
+plot(forbes_prune, uniform = TRUE, margin = 0.1, branch = 0.5,
+     compress = TRUE)
 text(forbes_prune)
 rn <- rownames(forbes_prune$frame)
 lev <- rn[sort(unique(forbes_prune$where))]
 where <- factor(rn[forbes_prune$where], levels = lev)
 n <- tapply(Forbes2000$profits, where, length)
 boxplot(Forbes2000$profits ~ where, varwidth = TRUE,
-        ylim = range(Forbes2000$profit) * 1.3, pars = list(axes =
-        FALSE), ylab = "Profits in US dollars")
+        ylim = range(Forbes2000$profit) * 1.3,
+        pars = list(axes = FALSE),
+        ylab = "Profits in US dollars")
 abline(h = 0, lty = 3)
 axis(2)
-text(1:length(n), max(Forbes2000$profit) * 1.2, paste("n = ", n))
+text(1:length(n), max(Forbes2000$profit) * 1.2,
+     paste("n = ", n))
 
 
 ###################################################
@@ -106,12 +124,14 @@ glaucoma_prune <- prune(glaucoma_rpart, cp = cp)
 ### chunk number 11: RP-glaucoma-plot
 ###################################################
 layout(matrix(1:2, nc = 1))
-plot(glaucoma_prune, uniform = TRUE, margin = 0.1, branch = 0.5, compress = TRUE)
+plot(glaucoma_prune, uniform = TRUE, margin = 0.1, branch = 0.5,
+     compress = TRUE)
 text(glaucoma_prune, use.n = TRUE)
 rn <- rownames(glaucoma_prune$frame)
 lev <- rn[sort(unique(glaucoma_prune$where))]
 where <- factor(rn[glaucoma_prune$where], levels = lev)
-mosaicplot(table(where, GlaucomaM$Class), main = "", xlab = "", las = 1)
+mosaicplot(table(where, GlaucomaM$Class), main = "", xlab = "",
+           las = 1)
 
 
 ###################################################
@@ -131,7 +151,8 @@ table(nsplitopt)
 trees <- vector(mode = "list", length = 25)
 n <- nrow(GlaucomaM)
 bootsamples <- rmultinom(length(trees), n, rep(1, n)/n)
-mod <- rpart(Class ~ ., data = GlaucomaM, control = rpart.control(xval = 0))
+mod <- rpart(Class ~ ., data = GlaucomaM,
+             control = rpart.control(xval = 0))
 for (i in 1:length(trees))
     trees[[i]] <- update(mod, weights = bootsamples[,i])
 
@@ -147,7 +168,8 @@ table(sapply(trees, function(x) as.character(x$frame$var[1])))
 ###################################################
 classprob <- matrix(0, nrow = n, ncol = length(trees))
 for (i in 1:length(trees)) {
-    classprob[,i] <- predict(trees[[i]], newdata = GlaucomaM)[,2]
+    classprob[,i] <- predict(trees[[i]],
+                             newdata = GlaucomaM)[,1]
     classprob[bootsamples[,i] > 0,i] <- NA
 }
 
@@ -156,7 +178,7 @@ for (i in 1:length(trees)) {
 ### chunk number 16: RP-glaucoma-avg
 ###################################################
 avg <- rowMeans(classprob, na.rm = TRUE)
-predictions <- factor(avg > 0.5, labels = levels(GlaucomaM$Class))
+predictions <- factor(ifelse(avg > 0.5, "glaucoma", "normal"))
 predtab <- table(predictions, GlaucomaM$Class)
 predtab
 
@@ -178,9 +200,10 @@ round(predtab[2,2] / colSums(predtab)[2] * 100)
 ###################################################
 library("lattice")
 gdata <- data.frame(avg = rep(avg, 2),
-                    class = rep(as.numeric(GlaucomaM$Class), 2),
-                    obs = c(GlaucomaM[["varg"]], GlaucomaM[["vari"]]),
-                    var = factor(c(rep("varg", nrow(GlaucomaM)), rep("vari", nrow(GlaucomaM)))))
+    class = rep(as.numeric(GlaucomaM$Class), 2),
+    obs = c(GlaucomaM[["varg"]], GlaucomaM[["vari"]]),
+    var = factor(c(rep("varg", nrow(GlaucomaM)),
+                   rep("vari", nrow(GlaucomaM)))))
 panelf <- function(x, y) {
            panel.xyplot(x, y, pch = gdata$class)
            panel.abline(h = 0.5, lty = 2)
